@@ -40,6 +40,9 @@
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/libgnometypebuiltins.h>
+#include <gconf/gconf-client.h>
+#include <gtk/gtkoptionmenu.h>
+
 
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -69,6 +72,8 @@ const gchar *crash_type[] = {
 PoptData popt_data;
 
 DruidData druid_data;
+GConfClient *conf_client;
+
 
 static const struct poptOption options[] = {
 	{ "name",        0, POPT_ARG_STRING, &popt_data.name,         0, N_("Name of contact"),                    N_("NAME") },
@@ -238,26 +243,31 @@ on_gdb_copy_clicked (GtkWidget *w, gpointer data)
 void
 on_gdb_save_clicked (GtkWidget *w, gpointer data)
 {
-	GtkWidget *filesel;
+	GtkWidget *filechooser;
 	int response;
 
-	filesel = gtk_file_selection_new (_("Save Backtrace"));
+	filechooser = gtk_file_chooser_dialog_new (_("Save Backtrace"),
+						   NULL,
+						   GTK_FILE_CHOOSER_ACTION_SAVE,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+						   NULL);
  run_save_dialog:
-	response = gtk_dialog_run (GTK_DIALOG (filesel));
+	response = gtk_dialog_run (GTK_DIALOG (filechooser));
 	if (response == GTK_RESPONSE_OK) {
-		const char *file;
+		char *file;
 		GError *gerr = NULL;
 		char *text;
 
-		file = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
+		file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooser));
 		text = buddy_get_text ("gdb-text");
-		if (!bb_write_buffer_to_file (GTK_WINDOW (filesel), 
+		if (!bb_write_buffer_to_file (GTK_WINDOW (filechooser), 
 					      _("Please wait while Bug Buddy saves the stack trace..."),
 					      file, text, -1, &gerr)) {
 			if (gerr) {
 				GtkWidget *d;
 				
-				d = gtk_message_dialog_new (GTK_WINDOW (filesel),
+				d = gtk_message_dialog_new (GTK_WINDOW (filechooser),
 							    0,
 							    GTK_MESSAGE_ERROR,
 							    GTK_BUTTONS_OK,
@@ -269,33 +279,26 @@ on_gdb_save_clicked (GtkWidget *w, gpointer data)
 				gtk_widget_destroy (d);
 				g_error_free (gerr);
 			}
+			g_free (file);
 			g_free (text);
 			goto run_save_dialog;
 		}
 
+		g_free (file);
 		g_free (text);
 	}
 	
-	gtk_widget_destroy (filesel);
+	gtk_widget_destroy (filechooser);
 }
 
 void
-on_product_toggle_clicked (GtkWidget *w, gpointer data)
+on_applications_products_changed (GtkWidget *w, gpointer data)
 {
-	char *button;
 
 	g_return_if_fail (druid_data.state == STATE_PRODUCT);
 
 	druid_data.show_products = !druid_data.show_products;
 
-	if (druid_data.show_products) {
-		button = _("Show _Applications");
-	} else {
-		button = _("Show _Products");
-	}
-
-	buddy_set_text ("product-toggle",    button);
-
 	products_list_load ();
 }
 
@@ -429,7 +432,7 @@ init_gnome_version_stuff (void)
 	xmlDoc *doc;
 	char *xml_file;
 	xmlNode *node;
-	char *platform, *minor, *micro, *distributor;
+	char *platform, *minor, *micro, *distributor, *date;
 
 
 	druid_data.gnome_version = g_getenv ("BUG_BUDDY_GNOME_VERSION");
@@ -440,6 +443,8 @@ init_gnome_version_stuff (void)
 	if (!xml_file)
 		return;
 	doc = xmlParseFile (xml_file);
+	g_free (xml_file);
+
 	if (!doc)
 		return;
 
@@ -454,6 +459,8 @@ init_gnome_version_stuff (void)
 			micro = xmlNodeGetContent (node);
 		else if (!strcmp (node->name, "distributor"))
 			distributor = xmlNodeGetContent (node);
+		else if (!strcmp (node->name, "date"))
+			date = xmlNodeGetContent (node);
 	}
 	
 	if (platform && minor && micro)
@@ -462,10 +469,14 @@ init_gnome_version_stuff (void)
 	if (distributor && *distributor)
 		druid_data.gnome_distributor = g_strdup (distributor);
 	
+	if (date && *date)
+		druid_data.gnome_date = g_strdup (date);
+
 	xmlFree (platform);
 	xmlFree (minor);
 	xmlFree (micro);
 	xmlFree (distributor);
+	xmlFree (date);
 	
 	xmlFreeDoc (doc);
 }
@@ -482,7 +493,9 @@ init_ui (void)
 	
 	glade_xml_signal_autoconnect (druid_data.xml);
 
-	load_config ();
+	init_gconf_stuff ();
+
+	druid_data.show_products = FALSE;
 
 	/* gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL); */
 
@@ -524,7 +537,7 @@ init_ui (void)
 	}
 
 	/* package version */
-	buddy_set_text ("the-version-entry", popt_data.package_ver);
+	druid_data.version = popt_data.package_ver;
 
         /* init some ex-radio buttons */
 	m = gtk_menu_new ();
@@ -578,66 +591,29 @@ init_ui (void)
 					  NULL);
 	}
 
-	buddy_set_text ("desc-text",
-			"Description of Problem:\n\n\n"
-			"Steps to reproduce the problem:\n"
-			"1. \n"
-			"2. \n"
-			"3. \n\n"
-			"Actual Results:\n\n\n"
-			"Expected Results:\n\n\n"
-			"How often does this happen?\n\n\n"
-			"Additional Information:\n");
-
-	/* set the cursor at the beginning of the second line */
+	/* crearte lock tag for the email review page */
 	{
-		GtkTextBuffer *buffy;
-		GtkTextIter iter;
+		GtkTextBuffer *email_buffer;
+		GtkTextTag *tag;
 
-		buffy = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
-		gtk_text_buffer_get_iter_at_line (buffy, &iter, 1);
-		gtk_text_buffer_place_cursor (buffy, &iter);
-	}
-}
-
-GtkWidget *
-make_image (char *widget_name, char *icon, char *s2, int stock, int i2)
-{
-	GtkWidget *w = NULL;
-
-	if (stock) {
-		GtkIconSize size = GTK_ICON_SIZE_BUTTON;
-
-		if (s2)
-			size = glade_enum_from_string (GTK_TYPE_ICON_SIZE, s2);
-
-		w = gtk_image_new_from_stock (icon, size);
-	} else {
-		GnomeFileDomain domain = GNOME_FILE_DOMAIN_APP_PIXMAP;
-		char *filename;
-		
-		if (s2)
-			domain = glade_enum_from_string (GNOME_TYPE_FILE_DOMAIN, s2);
-
-		filename = gnome_program_locate_file (NULL, domain, icon, TRUE, NULL);
-
-		if (filename)
-			w = gtk_image_new_from_file (filename);
-		else
-			g_warning (_("Could not find pixmap: %s (%d)\n"), icon, domain);
-		g_free (filename);
+		email_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW
+						(GET_WIDGET ("email-text")));
+		tag = gtk_text_buffer_create_tag (email_buffer, "lock_tag",
+						"editable", FALSE, NULL);
 	}
 
-	if (w)
-		gtk_widget_show (w);
 
-	return w;
+
+
 }
 
 gint
 delete_me (GtkWidget *w, GdkEventAny *evt, gpointer data)
 {
-	save_config ();
+	if (druid_data.last_update_check > 0) {
+                gconf_client_set_int (conf_client, "/apps/bug-buddy/last_update_check",
+				      time(NULL), NULL);
+	}
 	gtk_main_quit ();
 	return FALSE;
 }
@@ -653,6 +629,7 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *w;
+	GtkIconInfo *icon_info;
 	char *s;
 		
 	memset (&druid_data, 0, sizeof (druid_data));
@@ -672,12 +649,12 @@ main (int argc, char *argv[])
 			    GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
 			    NULL);
 
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, 
-				       "bug-buddy.png", TRUE, NULL);
-	
-	if (s)
-		gnome_window_icon_set_default_from_file (s);
-	g_free (s);
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
+						"bug-buddy", 48, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+        }
 
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 				       "bug-buddy/bug-buddy.glade", TRUE, NULL);
@@ -712,6 +689,7 @@ main (int argc, char *argv[])
 	if (druid_data.need_to_download) {
 		int response;
 		if (gtk_dialog_run (GTK_DIALOG (GET_WIDGET ("update-dialog"))) == GTK_RESPONSE_OK) {
+			gtk_widget_destroy (GET_WIDGET ("update-dialog"));
 			start_bugzilla_download ();
 			response = gtk_dialog_run (GTK_DIALOG (GET_WIDGET ("progress-dialog")));
 			if (response == GTK_RESPONSE_CANCEL) {
@@ -719,6 +697,7 @@ main (int argc, char *argv[])
 				gtk_widget_destroy(GET_WIDGET ("progress-dialog"));
 				druid_data.download_in_progress = FALSE;
 			} else if (response == DOWNLOAD_FINISHED_ZERO_RESPONSE) {
+				gtk_widget_destroy(GET_WIDGET ("progress-dialog"));
 				w = gtk_message_dialog_new (NULL,
 							    0,
 							    GTK_MESSAGE_ERROR,
@@ -730,27 +709,14 @@ main (int argc, char *argv[])
 						 		GTK_RESPONSE_OK);
 				gtk_dialog_run (GTK_DIALOG (w));
 				gtk_widget_destroy (w);
-
-				gtk_widget_destroy(GET_WIDGET ("progress-dialog"));
 			} else if (response == DOWNLOAD_FINISHED_OK_RESPONSE) {
-				w = gtk_message_dialog_new (NULL,
-							    0,
-							    GTK_MESSAGE_INFO,
-							    GTK_BUTTONS_OK,
-							    _("Bug Buddy updated its bug information correctly."));
-					      
-				gtk_dialog_set_default_response (GTK_DIALOG (w),
-						 		GTK_RESPONSE_OK);
-				gtk_dialog_run (GTK_DIALOG (w));
-				gtk_widget_destroy (w);
-
 				gtk_widget_destroy(GET_WIDGET ("progress-dialog"));
 			}
+		} else {
+			gtk_widget_destroy (GET_WIDGET ("update-dialog"));
 		}
-		
-		gtk_widget_destroy (GET_WIDGET ("update-dialog"));
 	}
-	
+
 	load_bugzilla_xml ();
 
 	gtk_widget_show (GET_WIDGET ("druid-window"));
